public inbox for u-boot@lists.denx.de
 help / color / mirror / Atom feed
* [U-Boot] [PATCH 1/2] tegra: display: add board pinmux
@ 2012-11-25 21:26 Marc Dietrich
  2012-11-25 21:26 ` [U-Boot] [PATCH 2/2] tegra: enable LCD on PAZ00 Marc Dietrich
  2012-11-26 16:55 ` [U-Boot] [PATCH 1/2] tegra: display: add board pinmux Tom Warren
  0 siblings, 2 replies; 10+ messages in thread
From: Marc Dietrich @ 2012-11-25 21:26 UTC (permalink / raw)
  To: u-boot

Boards may require a different pinmux setup for DISPALY than the default one.
Add a way to call into board specific code to set this up.

Signed-off-by: Marc Dietrich <marvin24@gmx.de>
---
 arch/arm/include/asm/arch-tegra/board.h |    7 ++++---
 board/nvidia/common/board.c             |    7 +++++++
 2 files changed, 11 insertions(+), 3 deletions(-)

diff --git a/board/nvidia/common/board.c b/board/nvidia/common/board.c
index 76ec687..819c120 100644
--- a/board/nvidia/common/board.c
+++ b/board/nvidia/common/board.c
@@ -87,6 +87,12 @@ void __pin_mux_nand(void)
 
 void pin_mux_nand(void) __attribute__((weak, alias("__pin_mux_nand")));
 
+void __pin_mux_display(void)
+{
+}
+
+void pin_mux_display(void) __attribute__((weak, alias("__pin_mux_display")));
+
 /*
  * Routine: power_det_init
  * Description: turn off power detects
@@ -126,6 +132,7 @@ int board_init(void)
 		debug("%s: Failed to init pwm\n", __func__);
 #endif
 #ifdef CONFIG_LCD
+	pin_mux_display();
 	tegra_lcd_check_next_stage(gd->fdt_blob, 0);
 #endif
 	/* boot param addr */
diff --git a/arch/arm/include/asm/arch-tegra/board.h b/arch/arm/include/asm/arch-tegra/board.h
index be6bf25..3db0d93 100644
--- a/arch/arm/include/asm/arch-tegra/board.h
+++ b/arch/arm/include/asm/arch-tegra/board.h
@@ -41,8 +41,9 @@ void gpio_early_init(void);  /* overrideable GPIO config        */
  * an empty stub function will be called.
  */
 
-void pin_mux_usb(void);      /* overrideable USB pinmux setup   */
-void pin_mux_spi(void);      /* overrideable SPI pinmux setup   */
-void pin_mux_nand(void);     /* overrideable NAND pinmux setup  */
+void pin_mux_usb(void);      /* overrideable USB pinmux setup     */
+void pin_mux_spi(void);      /* overrideable SPI pinmux setup     */
+void pin_mux_nand(void);     /* overrideable NAND pinmux setup    */
+void pin_mux_display(void);  /* overrideable DISPLAY pinmux setup */
 
 #endif
-- 
1.7.9.5

^ permalink raw reply related	[flat|nested] 10+ messages in thread

end of thread, other threads:[~2012-11-27 21:59 UTC | newest]

Thread overview: 10+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2012-11-25 21:26 [U-Boot] [PATCH 1/2] tegra: display: add board pinmux Marc Dietrich
2012-11-25 21:26 ` [U-Boot] [PATCH 2/2] tegra: enable LCD on PAZ00 Marc Dietrich
2012-11-26 19:00   ` Stephen Warren
2012-11-26 21:00     ` Marc Dietrich
2012-11-27  0:07       ` Tom Warren
2012-11-27 17:42         ` Stephen Warren
2012-11-27 19:53           ` Stephen Warren
2012-11-27 21:59             ` Marek Vasut
2012-11-26 16:55 ` [U-Boot] [PATCH 1/2] tegra: display: add board pinmux Tom Warren
2012-11-26 20:51   ` Marc Dietrich

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox